develooper Front page | perl.perl5.porters | Postings from March 2003

[PATCH] FreeBSD 5.0 gethostbyaddr_r hints update

Thread Next
From:
Kay Roepke
Date:
March 6, 2003 16:45
Subject:
[PATCH] FreeBSD 5.0 gethostbyaddr_r hints update
Message ID:
3E67C4EA.A55FFE5C@dolphin-services.de

Hi!

Unfortunately FreeBSD 5.0-release still has this bug.

Patch follows.

Kay


--- hints/freebsd.sh~	Wed Dec 11 12:29:50 2002
+++ hints/freebsd.sh	Thu Mar  6 22:53:42 2003
@@ -220,7 +220,8 @@
 	      fi
 	      ldflags="-pthread $ldflags"
 	      case "$osvers" in
-	      4.*)	# 4.x has gethostbyaddr_r but it is
+	      4.*|5.0-release*)	
+			# 4.x and 5.0-release have gethostbyaddr_r but it is
 			# "Temporary function, not threadsafe"...
 			d_gethostbyaddr_r="undef"
 			d_gethostbyaddr_r_proto="undef"

Thread Next


nntp.perl.org: Perl Programming lists via nntp and http.
Comments to Ask Bjørn Hansen at ask@perl.org | Group listing | About